/***********************************************************************

 SV1Codec file I/O routines
 (header file)

 This file is a part of SV1Codec.
 SV1Codec is Copyright (C) 2002 by Marcin Grzegorczyk.

 Permission is granted to copy and redistribute this file under the
 terms of the Open Source MIT License. For more information please refer
 to the file sv1codec.c or to the SV1Codec documentation.

***********************************************************************/

#ifndef SV1C_IO_H
#define SV1C_IO_H

#include "sv1codec.h"

#include <stdio.h>  /* FILE, EOF, ... */

/*
 File stream description structure
*/
struct sStreamInfo {
  FILE *stream;             /* pointer to the stream */
  const char *filename;     /* file name, NULL if a special stream such as stdout */
  Bool newfileflag;         /* true if the file is being created, false if it's being updated */
};


PUBLIC_DECLARATION int WriteData(const void *ptr, size_t n, struct sStreamInfo *const streaminfo);
PUBLIC_DECLARATION char *SearchGameFile(const struct sOpParameters *const opp, const struct sFilesInfo *const finfo, const char *const title);
PUBLIC_DECLARATION int LoadInFile(struct sFilesInfo *const finfo);
PUBLIC_DECLARATION int CreateOrOpenOutputFile(const Bool create, struct sStreamInfo *const outs);
PUBLIC_DECLARATION int SeekFileOffset(struct sStreamInfo *const streaminfo, long offset);
PUBLIC_DECLARATION int CloseOutputFile(struct sStreamInfo *const outs, const Bool delay_msg);
PUBLIC_DECLARATION int RLEDecodeToStream(const unsigned char *const src, const size_t size, struct sStreamInfo *const outstream);
PUBLIC_DECLARATION int RLEEncodeToStream(const unsigned char *const src, const size_t size, struct sStreamInfo *const outstream, uint32_t *const chksump, const int code_min, const int code_max);

#endif /* SV1C_IO_H */

